@@ -1,3 +1,4 @@
+from .decorators import generates
 from .exceptions import ImproperlyConfigured
 from .functions import (
     batch_fetch,
@@ -5,6 +6,9 @@ from .functions import (
     escape_like,
     primary_keys,
     render_statement,
+    render_expression,
+    create_mock_engine,
+    mock_engine,
     sort_query,
     table_name,
     with_backrefs
@@ -15,6 +19,8 @@ from .generic import generic_relationship
 from .proxy_dict import ProxyDict, proxy_dict
 from .types import (
     ArrowType,
+    Choice,
+    ChoiceType,
     ColorType,
     CountryType,
     Country,
@@ -22,6 +28,7 @@ from .types import (
     instrumented_list,
     InstrumentedList,
     IPAddressType,
+    LocaleType,
     Password,
     PasswordType,
     PhoneNumber,
@@ -38,7 +45,7 @@ from .types import (
 )
 
 
-__version__ = '0.16.25'
+__version__ = '0.19.0'
 
 
 __all__ = (
@@ -46,16 +53,22 @@ __all__ = (
     coercion_listener,
     defer_except,
     escape_like,
+    generates,
+    generic_relationship,
     instrumented_list,
     merge,
     primary_keys,
     proxy_dict,
     render_statement,
+    render_expression,
+    create_mock_engine,
+    mock_engine,
     sort_query,
     table_name,
     with_backrefs,
-    generic_relationship,
     ArrowType,
+    Choice,
+    ChoiceType,
     ColorType,
     CountryType,
     Country,
@@ -63,6 +76,7 @@ __all__ = (
     ImproperlyConfigured,
     InstrumentedList,
     IPAddressType,
+    LocaleType,
     Merger,
     NumberRange,
     NumberRangeException,
