@@ -8,6 +8,10 @@ from sqlalchemy.orm.attributes import (
 from sqlalchemy.orm.session import object_session
 
 
+class PathException(Exception):
+    pass
+
+
 class with_backrefs(object):
     """
     Marks given attribute path so that whenever its fetched with batch_fetch
@@ -27,7 +31,7 @@ class Path(object):
         self.entities = entities
         self.populate_backrefs = populate_backrefs
         if not isinstance(self.property, RelationshipProperty):
-            raise Exception(
+            raise PathException(
                 'Given attribute is not a relationship property.'
             )
         self.fetcher = self.fetcher_class(self)
@@ -65,7 +69,7 @@ class Path(object):
         elif isinstance(path, InstrumentedAttribute):
             attr = path
         else:
-            raise Exception('Unknown path type.')
+            raise PathException('Unknown path type.')
 
         return Path(entities, attr.property, populate_backrefs)
 
@@ -181,7 +185,7 @@ class CompositeFetcher(object):
             fetchers[0].path.model == fetcher.path.model
             for fetcher in fetchers
         ):
-            raise Exception(
+            raise PathException(
                 'Each relationship property must have the same class when '
                 'using CompositeFetcher.'
             )
@@ -223,7 +227,10 @@ class Fetcher(object):
     def __init__(self, path):
         self.path = path
         self.prop = self.path.property
-        self.parent_dict = defaultdict(list)
+        if self.prop.uselist:
+            self.parent_dict = defaultdict(list)
+        else:
+            self.parent_dict = defaultdict(lambda: None)
 
     @property
     def local_values_list(self):
@@ -242,13 +249,7 @@ class Fetcher(object):
 
     @property
     def local_column_names(self):
-        names = []
-        for local, remote in self.prop.local_remote_pairs:
-            for fk in remote.foreign_keys:
-                # TODO: make this support inherited tables
-                if fk.column.table in self.prop.parent.tables:
-                    names.append(local.name)
-        return names
+        return [local.name for local, remote in self.prop.local_remote_pairs]
 
     def parent_key(self, entity):
         return tuple(
@@ -288,12 +289,6 @@ class Fetcher(object):
         Populate batch fetched entities to parent objects.
         """
         for entity in self.path.entities:
-            # print (
-            #     "setting committed value for ",
-            #     entity,
-            #     " using local values ",
-            #     self.local_values(entity)
-            # )
             set_committed_value(
                 entity,
                 self.prop.key,
@@ -314,7 +309,7 @@ class Fetcher(object):
             return getattr(self.remote, names[0]).in_(
                 value[0] for value in self.local_values_list
             )
-        else:
+        elif len(names) > 1:
             conditions = []
             for entity in self.path.entities:
                 conditions.append(
@@ -329,26 +324,41 @@ class Fetcher(object):
                     )
                 )
             return sa.or_(*conditions)
+        else:
+            raise PathException(
+                'Could not obtain remote column names.'
+            )
 
     def fetch(self):
         for entity in self.related_entities:
             self.append_entity(entity)
 
+    @property
+    def remote_column_names(self):
+        return [remote.name for local, remote in self.prop.local_remote_pairs]
+
 
 class ManyToManyFetcher(Fetcher):
     @property
     def remote(self):
         return self.prop.secondary.c
 
+    @property
+    def local_column_names(self):
+        names = []
+        for local, remote in self.prop.local_remote_pairs:
+            for fk in remote.foreign_keys:
+                if fk.column.table in self.prop.parent.tables:
+                    names.append(local.name)
+        return names
+
     @property
     def remote_column_names(self):
         names = []
         for local, remote in self.prop.local_remote_pairs:
             for fk in remote.foreign_keys:
-                # TODO: make this support inherited tables
-                if fk.column.table == self.path.parent_model.__table__:
-                    names.append(fk.parent.name)
-
+                if fk.column.table in self.prop.parent.tables:
+                    names.append(remote.name)
         return names
 
     @property
@@ -375,22 +385,10 @@ class ManyToManyFetcher(Fetcher):
 
 
 class ManyToOneFetcher(Fetcher):
-    def __init__(self, path):
-        Fetcher.__init__(self, path)
-        self.parent_dict = defaultdict(lambda: None)
-
     def append_entity(self, entity):
         #print 'appending entity ', entity, ' to key ', self.parent_key(entity)
         self.parent_dict[self.parent_key(entity)] = entity
 
-    @property
-    def remote_column_names(self):
-        return [remote.name for local, remote in self.prop.local_remote_pairs]
-
-    @property
-    def local_column_names(self):
-        return [local.name for local, remote in self.prop.local_remote_pairs]
-
 
 class OneToManyFetcher(Fetcher):
     def append_entity(self, entity):
@@ -398,14 +396,3 @@ class OneToManyFetcher(Fetcher):
         self.parent_dict[self.parent_key(entity)].append(
             entity
         )
-
-    @property
-    def remote_column_names(self):
-        names = []
-        for local, remote in self.prop.local_remote_pairs:
-            for fk in remote.foreign_keys:
-                # TODO: make this support inherited tables
-                if fk.column.table == self.path.parent_model.__table__:
-                    names.append(fk.parent.name)
-
-        return names
