@@ -1,10 +1,12 @@
 from functools import wraps
 from sqlalchemy.orm.collections import InstrumentedList as _InstrumentedList
 from .arrow import ArrowType
+from .choice import ChoiceType, Choice
 from .color import ColorType
 from .country import CountryType, Country
 from .email import EmailType
 from .ip_address import IPAddressType
+from .locale import LocaleType
 from .number_range import (
     NumberRange,
     NumberRangeException,
@@ -16,17 +18,21 @@ from .phone_number import PhoneNumber, PhoneNumberType
 from .scalar_list import ScalarListException, ScalarListType
 from .timezone import TimezoneType
 from .ts_vector import TSVectorType
+from .url import URLType
 from .uuid import UUIDType
 from .weekdays import WeekDay, WeekDays, WeekDaysType
 
 
 __all__ = (
     ArrowType,
+    Choice,
+    ChoiceType,
     ColorType,
     CountryType,
     Country,
     EmailType,
     IPAddressType,
+    LocaleType,
     NumberRange,
     NumberRangeException,
     NumberRangeRawType,
@@ -39,6 +45,7 @@ __all__ = (
     ScalarListType,
     TimezoneType,
     TSVectorType,
+    URLType,
     UUIDType,
     WeekDay,
     WeekDays,
